@@ -1,7 +1,7 @@
 package HTTP::Engine;
 use 5.00800;
 use Any::Moose;
-our $VERSION = '0.1.7';
+our $VERSION = '0.1.8';
 use HTTP::Engine::Request;
 use HTTP::Engine::Response;
 use HTTP::Engine::Types::Core qw( Interface );
@@ -119,13 +119,23 @@ The community can be found via:
 
   IRC: irc.perl.org#http-engine irc.freenode.net#coderepos
 
+  Mailing list: http://lists.scsys.co.uk/cgi-bin/mailman/listinfo/http-engine
+
+  GitHub: http://github.com/http-engine/HTTP-Engine
+
+  Twitter: http://twitter.com/httpengine
+
+The following things are no longer used
+
   Wiki Page: http://coderepos.org/share/wiki/HTTP%3A%3AEngine
 
   SVN: http://svn.coderepos.org/share/lang/perl/HTTP-Engine  
 
   Trac: http://coderepos.org/share/browser/lang/perl/HTTP-Engine
 
-  Mailing list: http://lists.scsys.co.uk/cgi-bin/mailman/listinfo/http-engine
+=head1 FOLLOWER DOCUMENTS
+
+L<http://en.wikibooks.org/wiki/Perl_Programming/HTTP::Engine> writing by gugod++.
 
 =head1 INTERFACES
 
@@ -244,6 +254,10 @@ gugod
 
 stevan
 
+hirose31
+
+fujiwara
+
 =head1 SEE ALSO
 
 L<HTTP::Engine::Middleware>,
@@ -255,9 +269,11 @@ L<Moose>
 
 =head1 REPOSITORY
 
-  svn co http://svn.coderepos.org/share/lang/perl/HTTP-Engine/trunk HTTP-Engine
+We moved to GitHub.
 
-HTTP::Engine's Subversion repository is hosted at L<http://coderepos.org/share/>.
+  git clone git://github.com/http-engine/HTTP-Engine.git
+
+HTTP::Engine's Git repository is hosted at L<http://github.com/http-engine/HTTP-Engine>.
 patches and collaborators are welcome.
 
 =head1 LICENSE
